@@ -3,7 +3,7 @@
 pub mod plugin_models;
 pub mod plugin_manager;
 mod child_process;
-mod proto;
+pub mod proto;
 pub mod catalogue_manager;
 pub mod content;
 pub mod utils;
